// jQuery Alert Dialogs Plugin
//
// Version 1.1
//
// Heavily modified for Humax PVR by adrianf36
// Details of original code as below.
//
// Cory S.N. LaViska
// A Beautiful Site (http://abeautifulsite.net/)
// 14 May 2009
//
// Visit http://abeautifulsite.net/notebook/87 for more information
//
// Usage:
//		jAlert( message, [title, callback] )
//		jConfirm( message, [title, callback] )
//		jPrompt( message, [value, title, callback] )
// 
// History:
//
//		1.00 - Released (29 December 2008)
//
//		1.01 - Fixed bug where unbinding would destroy all resize events
//
// License:
// 
// This plugin is dual-licensed under the GNU General Public License and the MIT License and
// is copyright 2008 A Beautiful Site, LLC. 
//
(function($) {
	
	$.alerts = {
		
		// Public methods
		
		alert: function(message, title, callback) {
			if( title == null ) title = 'Alert';
			$.alerts._show(title, message, null, 'alert', function(result) {
				if( callback ) callback(result);
			});
		},
		
		confirm: function(message, title, callback) {
			if( title == null ) title = 'Confirm';
			$.alerts._show(title, message, null, 'confirm', function(result) {
				if( callback ) callback(result);
			});
		},
			
		prompt: function(message, value, title, callback) {
			if( title == null ) title = 'Prompt';
			$.alerts._show(title, message, value, 'prompt', function(result) {
				if( callback ) callback(result);
			});
		},
		
		// Private methods
		
		_show: function(title, msg, value, type, callback) {
			
			$.alerts._hide();
			
			$("BODY").append(
			  '<div id="popup_container" title="' + title +'">' +
			    '<div id="popup_content">' +
			      '<div id="popup_message"></div>' +
				'</div>' +
			  '</div>');
			
			$("#popup_content").addClass(type);
			$("#popup_message").text(msg);
			$("#popup_message").html( $("#popup_message").text().replace(/\n/g, '<br />') );
			
			switch( type ) {
				case 'alert':
					$('#popup_container').dialog({
						autoOpen: false,
						height: 'auto', width: 'auto',
						modal: true,
						buttons: {
							"OK": function() {
									$.alerts._hide();
									if (callback) callback(true);
							}
						},
						close: function() { 
							$.alerts._hide();
							if (callback) callback(true);
						}
					});
				break;
				case 'confirm':
					$('#popup_container').dialog({
						autoOpen: false,
						height: 'auto', width: 'auto',
						modal: true,
						buttons: {
							"OK": function() {
									$.alerts._hide();
									if (callback) callback(true);
								},
							"Cancel": function() {
									$.alerts._hide();
									if (callback) callback(false);
							}
						},
						close: function() { 
							$.alerts._hide();
							if (callback) callback(false);
						}
					});
				break;
				case 'prompt':
					$("#popup_message").append('<br /><input type="text" size="70" id="popup_prompt" class="text ui-widget-content ui-corner-all" />');
					
					$('#popup_container').dialog({
						autoOpen: false,
						height: 'auto', width: 'auto',
						modal: true,
						buttons: {
							"OK": function() {
									var val = $("#popup_prompt").val();
									$.alerts._hide();
									if (callback) callback(val);
								},
							"Cancel": function() {
									$.alerts._hide();
									if (callback) callback(null);
							}
						},
						close: function() { 
							$.alerts._hide();
							if (callback) callback(null);
						}
					});

					if( value ) $("#popup_prompt").val(value);
					$("#popup_prompt").focus().select();
					break;
			}
			$('#popup_container').dialog('open');
		},
		
		_hide: function() {
			$("#popup_container").remove();
		}
	}
	
	// Shortuct functions
	jAlert = function(message, title, callback) {
		$.alerts.alert(message, title, callback);
	}
	
	jConfirm = function(message, title, callback) {
		$.alerts.confirm(message, title, callback);
	};
		
	jPrompt = function(message, value, title, callback) {
		$.alerts.prompt(message, value, title, callback);
	};
	
})(jQuery);